/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2010 EBM WebSourcing - http://www.petalslink.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.se.xslt.model;

/**
 * A bean that defines a XSL parameter for the XSLT SE.
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class XslParameterBean {

    /**
     * The parameter's name.
     */
    private String name;

    /**
     * The parameter's value.
     */
    private Object value;

    /**
     * True if this parameter can be overridden by a message property.
     */
    private boolean overridable;

    /**
     * Constructor.
     *
     * @param name
     *            the parameter's name
     * @param value
     *            the parameter's value
     * @param overridable
     *            defines whether the parameter value can be overriden at
     *            runtime
     */
    public XslParameterBean(String name, Object value, boolean overridable) {
        this.name = name;
        this.value = value;
        this.overridable = overridable;
    }

    /**
     * @return the name
     */
    public String getName() {
        return this.name;
    }

    /**
     * @param name
     *            the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * @return the value
     */
    public Object getValue() {
        return this.value;
    }

    /**
     * @param value
     *            the value to set
     */
    public void setValue(Object value) {
        this.value = value;
    }

    /**
     * @return the overridable
     */
    public boolean isOverridable() {
        return this.overridable;
    }

    /**
     * @param overridable
     *            the overridable to set
     */
    public void setOverridable(boolean overridable) {
        this.overridable = overridable;
    }
}
